using System;
using System.Data;
using System.Collections;

using NUnit.Framework;

using Lattice.Mapping;
using Lattice.Common;

namespace Lattice.DataMapper.UnitTest
{
	/// <summary>
	/// Summary description for testDAL.
	/// </summary>
	[TestFixture]
	public class testDAL
	{
		IDataMapper mapper = null;

		[SetUp]
		public void SetUp()
		{
			mapper = DataManager.Instance.Create();
		}

		[Test]
		public void testExecuteReader()
		{
			Criteria criteria = new Criteria();
			criteria.CommandName = "Customers_GetSingle";
			criteria.CommandType = CommandType.StoredProcedure;
			criteria.AddParameter("@CustomerID", "ALFKI" );
			
			IDataReader reader = mapper.ExecuteReader( criteria );

			while( reader.Read() )
			{
				Console.Write( "\tCustomer ID: " + reader["CustomerId"]);
				Console.Write( "\tOrderID: " + reader["OrderID"]);
				Console.Write(Environment.NewLine);
			}
		}

		[Test]
		public void testExecuteDataSet()
		{
			Criteria criteria = new Criteria();
			criteria.CommandName = "Customers_GetSingle";
			criteria.CommandType = CommandType.StoredProcedure;
			criteria.AddParameter("@CustomerID", "ALFKI" );

			DataSet ds = mapper.ExecuteDataSet( criteria );
			DataTable dt = ds.Tables[0];

			foreach( DataRow dr in dt.Rows )
			{
				Console.Write( "Customer ID: " + dr["CustomerID"]);
				Console.Write( "OrderID: " + dr["OrderID"]);
				Console.Write(Environment.NewLine);
			}
		}

		[Test]
		public void testExecuteScalar()
		{
			Criteria criteria = new Criteria();
			criteria.CommandName = "select companyname from customers where customerid = @CustomerID";
			criteria.CommandType = CommandType.Text;
			criteria.AddParameter("@CustomerID", "ALFKI" );

			string name = (string)mapper.ExecuteScalar(  criteria );

			Assert.AreEqual( "Alfreds Futterkiste", name );
		}
	}
}
